#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-asn1-parse
version:              0.10.0
visibility:           public
id:                   crypton-asn1-parse-0.10.0-ID3wNdJ2OrFNgEaiobPS5
key:                  crypton-asn1-parse-0.10.0-ID3wNdJ2OrFNgEaiobPS5
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    Mike Pilgrem <public@pilgrem.com>,
    Kazu Yamamoto <kazu@iij.ad.jp>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/mpilgrem/crypton-asn1
synopsis:             A monadic parser combinator for a ASN.1 stream.
description:
    A library providing a monadic parser combinator for use with a stream of
    Abstract Syntax Notation One (ASN.1) standard values.

category:             Data
abi:                  e8cbc3ae38c8c60b7da68a00c0ce0c05
exposed:              True
exposed-modules:
    Data.ASN1.Parse,
    Data.ASN1.Types from crypton-asn1-types-0.4.1-Jrk3cuijpL3DWQGNOXhzA5:Data.ASN1.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-asn1-parse-0.10.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-asn1-parse-0.10.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-asn1-parse-0.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-asn1-parse
hs-libraries:         HScrypton-asn1-parse-0.10.0-ID3wNdJ2OrFNgEaiobPS5
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    crypton-asn1-types-0.4.1-Jrk3cuijpL3DWQGNOXhzA5

haddock-interfaces:
    /usr/share/doc/haskell-crypton-asn1-parse/html/crypton-asn1-parse.haddock

haddock-html:         /usr/share/doc/haskell-crypton-asn1-parse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

